# Goof

Notify humans and machines, [DWIM].

## About

Goof supports Rapporto's "notify" subsystem. You can also use it in other
programs, either using its Python API, or its command-line interface.

## Notifiers

Goof currently supports Slack as a notification target.

```{toctree}
:maxdepth: 1
:hidden:

slack
```

::::{grid} 3
:gutter: 4

:::{grid-item-card} Slack
:link: slack
:link-type: doc
:class-card: sd-fs-2
:class-body: sd-text-center
:class-footer: sd-fs-6
{fab}`slack;sd-text-success fa-2xl`
+++
Tap into the Slack API and have conversations.
:::

::::


[DWIM]: https://en.wikipedia.org/wiki/DWIM
